pub struct LibraryAlbumAttributes {
pub artist_name: String,
pub artwork: Artwork,
pub content_rating: Option<ContentRating>,
pub date_added: Option<YearOrDate>,
pub name: String,
pub play_params: Option<PlayParameters>,
pub release_date: Option<YearOrDate>,
pub track_count: u32,
pub genre_names: Vec<String>,
}Expand description
Library album attributes
Fields
artist_name: StringThe artist’s name
artwork: ArtworkThe album artwork
content_rating: Option<ContentRating>The Recording Industry Association of America (RIAA) rating of the content. The possible values for this rating are clean and explicit. No value means no rating
date_added: Option<YearOrDate>The date the album was added to the library, in YYYY-MM-DD or YYYY format
name: StringThe localized name of the album
play_params: Option<PlayParameters>The parameters to use to playback the tracks of the album
release_date: Option<YearOrDate>The release date of the album, when known, in YYYY-MM-DD or YYYY format. Pre-release albums may have an expected release date in the future
track_count: u32The number of tracks
genre_names: Vec<String>The names of the genres associated with this album